## Description

**Tortick** (from Russian то́ртик, a diminutive for торт, "cake") is a Telegram-like channel for the Dark Web. It creates a Tor Hidden Service with JSON-speaking API, which allows to create text/flavoured posts and publish binaries (images, music, etc.). All posts and binaries are signed with Hidden Service Ed25519 key, which allows to verify authorship.

For now it works only with Unix-like systems (tested with Debian 12). Other systems support is planned for future releases.

**NOTE:** This is a pre-alpha. Server is working, but client is in progress of development. So, it does not look as beautiful as it can be.

## Dependencies

```bash
apt install tor obfs4proxy
```

## Usage

### Server side

Create a channel database:

```bash
tortick channel-new --name 'Test Channel' --info '{"author": "Anonymous Person", "email": "author@service.org"}' --db test_channel.db
```

Add a new post:

```bash
tortick post-new --db test_channel.db --text "Hi everyone! I've created my own tortick!" [--postpone ${NOT_NOW}]
```

Run the server. Also, you can specify Tor bridges:

```bash
tortick channel-run --db test_channel.db --bridges working_bridges.txt
```

Or, you can run your channel locally, at `localhost:8000`:

```bash
tortick channel-run --db test_channel.db --test
```

Get the full list of commands:

```bash
tortick --help
```

### API

**Last API version:** v0 (under development)

- `/api/v0/info`: Get channel public info
- `/api/v0/updates/{timestamp}`: Get Entity IDs (EntID) of all entities that were published (or edited) starting from `{timestamp}`. Returns 100 EntIDs at most. It is recommended to start getting updates from `/api/v0/updates/0`.
- `/api/v0/entity/{entid}`: Get Entity with specified `{entid}`. It can be Post, or Binary summary. Returns error if EntID does not exist.
- `/api/v0/binary/{entid}/{fragnum}`: Get fragment with number `{fragnum}` (started from 1) of the Binary with specified `{entid}`. Returns empty bytes in cause of any error.

## Bugs

If you find the project interesting and want to participate, feel free to report bugs and request features [here](https://codeberg.org/screwery/tortick/issues).
